@@ -137,8 +137,27 @@ def align_texts(splitted_from,
                  in get_batch_intersected(splitted_from, splitted_to, batch_size, window, batch_ids, batch_shift=shift, iter3=proxy_from, iter4=proxy_to)]
 
     for lines_from_batch, lines_to_batch, proxy_from_batch, proxy_to_batch, line_ids_from, line_ids_to, batch_id in task_list:
-        texts_from, texts_to = process_batch(lines_from_batch, lines_to_batch, proxy_from_batch, proxy_to_batch, line_ids_from,
-                                             line_ids_to, batch_id, model_name, window, embed_batch_size, normalize_embeddings, show_progress_bar, save_pic, lang_from, lang_to, img_path, show_info=show_info, show_regression=show_regression)
+        texts_from, texts_to = process_batch(
+            lines_from_batch,
+            lines_to_batch,
+            proxy_from_batch,
+            proxy_to_batch,
+            line_ids_from,
+            line_ids_to,
+            batch_id,
+            model_name,
+            window,
+            embed_batch_size,
+            normalize_embeddings,
+            show_progress_bar,
+            save_pic,
+            lang_from,
+            lang_to,
+            img_path,
+            show_info=show_info,
+            show_regression=show_regression,
+            use_proxy_from=use_proxy_from,
+            use_proxy_to=use_proxy_to)
         result.append((batch_id, texts_from, texts_to))
 
     # sort by batch_id (will be useful with parallel processing)
@@ -163,13 +182,14 @@ def align_db(db_path,
         show_info=False,
         show_regression=False,
         model=None,
-        proxy_from=[],
-        proxy_to=[],
         use_proxy_from=False,
         use_proxy_to=False):
     result = []
     splitted_from = get_splitted_from(db_path)
     splitted_to = get_splitted_to(db_path)
+    proxy_from = get_proxy_from(db_path)
+    proxy_to = get_proxy_to(db_path)
+
     task_list = [(lines_from_batch, lines_to_batch, proxy_from_batch, proxy_to_batch, line_ids_from, line_ids_to, batch_id)
                  for
                     lines_from_batch,
@@ -204,8 +224,8 @@ def align_db(db_path,
             show_info=show_info,
             show_regression=show_regression,
             model=model,
-            use_proxy_from=False,
-            use_proxy_to=False)
+            use_proxy_from=use_proxy_from,
+            use_proxy_to=use_proxy_to)
         result.append((batch_id, texts_from, texts_to, shift, window))
         count += 1
 
@@ -479,7 +499,7 @@ def load_proxy(db_path, filepath, direction):
         with open(filepath, mode="r", encoding="utf-8") as input_path:
             lines_proxy = input_path.readlines()
     ids = [x for x in range(1, len(lines_proxy)+1)]
-    with sqlite3.connect(db_path) as db:        
+    with sqlite3.connect(db_path) as db:
         if direction == "from":
             db.executemany("update splitted_from set proxy_text=(?) where id=(?)", [
                             (proxy, id) for id, proxy in zip(ids, lines_proxy)])
