@@ -14,12 +14,14 @@ H1, H2, H3, H4, H5 = "h1","h2","h3","h4","h5"
 DIVIDER = "divider"
 TITLE = "title"
 AUTHOR = "author"
+TRANSLATOR = "translator"
 QUOTE_TEXT = "qtext"
 QUOTE_NAME = "qname"
 IMAGE = "image"
 
+MARK_META = [H1, H2, H3, H4, H5, DIVIDER, TITLE, AUTHOR, QUOTE_TEXT, QUOTE_NAME, IMAGE, TRANSLATOR]
+
 MARK_COUNTERS = [H1, H2, H3, H4, H5, DIVIDER, QUOTE_TEXT, QUOTE_NAME, IMAGE]
-MARK_META = [H1, H2, H3, H4, H5, DIVIDER, TITLE, AUTHOR, QUOTE_TEXT, QUOTE_NAME, IMAGE]
 MARKS_FOR_ADDING = [H1, H2, H3, H4, H5, DIVIDER, QUOTE_TEXT, QUOTE_NAME, IMAGE]
 
 PARAGRAPH_MARK = "%%%%%"
