@@ -72,6 +72,11 @@ last_punct = re.compile(r'[,\.]+$')
 multiple_spaces = re.compile(r'\s+')
 pattern_ru = re.compile(r'[a-zA-Z\.\(\)\[\]\/\-\:!?\<\>;•\"\'«»——,]+')
 pattern_ru_letters_only = re.compile(r'[^а-яА-Я\s]+')
+german_foo = '%@%'
+german_months = 'Januar|Jänner|Janner|Februar|März|Marz|April|Mai|Juni|Juli|August|September|Oktober|October|November|Dezember'
+german_dates = re.compile(rf'(\s)(\d{{1,2}})\.(\s+)({german_months})')
+german_bdates  = re.compile(rf'(\s)(\d{{1,2}}){german_foo}(\s+)({german_months})')
+
 
 DEFAULT_PREPROCESSING = [
     (double_spaces, ' '),
@@ -116,9 +121,9 @@ def after_fr(lines):
 
 def preprocess_raw(lines, re_list):
     """Preprocess raw file lines"""
-    for i,line in enumerate(lines):
+    for i in range(len(lines)):
         for pat, val in re_list:
-            lines[i] = re.sub(pat, val, line)
+            lines[i] = re.sub(pat, val, lines[i])
     return lines
 
 
@@ -186,9 +191,13 @@ def split_by_sentences(lines, langcode):
     if langcode == DE_CODE:
         sentences = preprocess(line, [
             (german_quotes, '"'),
+            ( german_dates, rf'\1\2{german_foo}\3\4' ),
             *DEFAULT_PREPROCESSING
         ],
             split_by_razdel)
+        sentences = preprocess_raw(sentences, [
+            (german_bdates, r'\1\2.\3\4')
+        ])
         return sentences
     if langcode == ZH_CODE:
         sentences = preprocess(line, [
